.. kalabash-webmail documentation master file, created by
   sphinx-quickstart on Sun Apr  5 14:19:58 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to kalabash-webmail's documentation!
===========================================

Kalabash provides a simple webmail:

* Browse, read and compose messages, attachments are supported
* HTML messages are supported
* `CKeditor <http://ckeditor.com/>`_ integration
* Manipulate mailboxes (create, move, remove)
* Quota display

Contents:

.. toctree::
   :maxdepth: 2

   setup
